@@ -25,7 +25,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 
@@ -68,8 +68,7 @@
  * When necessary, #GtkMountOperation shows dialogs to ask for passwords.
  */
 
-/* GObject, GtkObject methods
- */
+static void   gtk_mount_operation_finalize     (GObject          *object);
 static void   gtk_mount_operation_set_property (GObject          *object,
                                                 guint             prop_id,
                                                 const GValue     *value,
@@ -78,10 +77,7 @@ static void   gtk_mount_operation_get_property (GObject          *object,
                                                 guint             prop_id,
                                                 GValue           *value,
                                                 GParamSpec       *pspec);
-static void   gtk_mount_operation_finalize     (GObject          *object);
 
-/* GMountOperation methods
- */
 static void   gtk_mount_operation_ask_password (GMountOperation *op,
                                                 const char      *message,
                                                 const char      *default_user,
@@ -92,6 +88,8 @@ static void   gtk_mount_operation_ask_question (GMountOperation *op,
                                                 const char      *message,
                                                 const char      *choices[]);
 
+static void   gtk_mount_operation_aborted      (GMountOperation *op);
+
 G_DEFINE_TYPE (GtkMountOperation, gtk_mount_operation, G_TYPE_MOUNT_OPERATION);
 
 enum {
@@ -102,7 +100,7 @@ enum {
 
 };
 
-struct GtkMountOperationPrivate {
+struct _GtkMountOperationPrivate {
   GtkWindow *parent_window;
   GtkDialog *dialog;
   GdkScreen *screen;
@@ -119,30 +117,11 @@ struct GtkMountOperationPrivate {
   gboolean          anonymous;
 };
 
-static void
-gtk_mount_operation_finalize (GObject *object)
-{
-  GtkMountOperation *operation;
-  GtkMountOperationPrivate *priv;
-
-  operation = GTK_MOUNT_OPERATION (object);
-
-  priv = operation->priv;
-
-  if (priv->parent_window)
-    g_object_unref (priv->parent_window);
-
-  if (priv->screen)
-    g_object_unref (priv->screen);
-
-  G_OBJECT_CLASS (gtk_mount_operation_parent_class)->finalize (object);
-}
-
 static void
 gtk_mount_operation_class_init (GtkMountOperationClass *klass)
 {
   GObjectClass         *object_class = G_OBJECT_CLASS (klass);
-  GMountOperationClass *mount_op_class;
+  GMountOperationClass *mount_op_class = G_MOUNT_OPERATION_CLASS (klass);
 
   g_type_class_add_private (klass, sizeof (GtkMountOperationPrivate));
 
@@ -150,9 +129,9 @@ gtk_mount_operation_class_init (GtkMountOperationClass *klass)
   object_class->get_property = gtk_mount_operation_get_property;
   object_class->set_property = gtk_mount_operation_set_property;
 
-  mount_op_class = G_MOUNT_OPERATION_CLASS (klass);
   mount_op_class->ask_password = gtk_mount_operation_ask_password;
   mount_op_class->ask_question = gtk_mount_operation_ask_question;
+  mount_op_class->aborted = gtk_mount_operation_aborted;
 
   g_object_class_install_property (object_class,
                                    PROP_PARENT,
@@ -175,11 +154,32 @@ gtk_mount_operation_class_init (GtkMountOperationClass *klass)
                                    g_param_spec_object ("screen",
                                                         P_("Screen"),
                                                         P_("The screen where this window will be displayed."),
-                                                        GTK_TYPE_WINDOW,
+                                                        GDK_TYPE_SCREEN,
                                                         GTK_PARAM_READWRITE));
-
 }
 
+static void
+gtk_mount_operation_init (GtkMountOperation *operation)
+{
+  operation->priv = G_TYPE_INSTANCE_GET_PRIVATE (operation,
+                                                 GTK_TYPE_MOUNT_OPERATION,
+                                                 GtkMountOperationPrivate);
+}
+
+static void
+gtk_mount_operation_finalize (GObject *object)
+{
+  GtkMountOperation *operation = GTK_MOUNT_OPERATION (object);
+  GtkMountOperationPrivate *priv = operation->priv;
+
+  if (priv->parent_window)
+    g_object_unref (priv->parent_window);
+
+  if (priv->screen)
+    g_object_unref (priv->screen);
+
+  G_OBJECT_CLASS (gtk_mount_operation_parent_class)->finalize (object);
+}
 
 static void
 gtk_mount_operation_set_property (GObject      *object,
@@ -187,25 +187,20 @@ gtk_mount_operation_set_property (GObject      *object,
                                   const GValue *value,
                                   GParamSpec   *pspec)
 {
-  GtkMountOperation *operation;
-  gpointer tmp;
-
-  operation = GTK_MOUNT_OPERATION (object);
+  GtkMountOperation *operation = GTK_MOUNT_OPERATION (object);
 
   switch (prop_id)
     {
-   case PROP_PARENT:
-     tmp = g_value_get_object (value);
-     gtk_mount_operation_set_parent (operation, tmp);
-     break;
+    case PROP_PARENT:
+      gtk_mount_operation_set_parent (operation, g_value_get_object (value));
+      break;
 
-   case PROP_SCREEN:
-      tmp = g_value_get_object (value);
-      gtk_mount_operation_set_screen (operation, tmp);
-     break;
+    case PROP_SCREEN:
+      gtk_mount_operation_set_screen (operation, g_value_get_object (value));
+      break;
 
-   case PROP_IS_SHOWING:
-   default:
+    case PROP_IS_SHOWING:
+    default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
     }
@@ -217,11 +212,8 @@ gtk_mount_operation_get_property (GObject    *object,
                                   GValue     *value,
                                   GParamSpec *pspec)
 {
-  GtkMountOperationPrivate *priv;
-  GtkMountOperation *operation;
-
-  operation = GTK_MOUNT_OPERATION (object);
-  priv = operation->priv;
+  GtkMountOperation *operation = GTK_MOUNT_OPERATION (object);
+  GtkMountOperationPrivate *priv = operation->priv;
 
   switch (prop_id)
     {
@@ -244,22 +236,18 @@ gtk_mount_operation_get_property (GObject    *object,
 }
 
 static void
-gtk_mount_operation_init (GtkMountOperation *operation)
-{
-  operation->priv = G_TYPE_INSTANCE_GET_PRIVATE (operation,
-                                                 GTK_TYPE_MOUNT_OPERATION,
-                                                 GtkMountOperationPrivate);
-}
-
-static void
-remember_button_toggled (GtkWidget         *widget,
+remember_button_toggled (GtkToggleButton   *button,
                          GtkMountOperation *operation)
 {
   GtkMountOperationPrivate *priv = operation->priv;
-  gpointer data;
 
-  data = g_object_get_data (G_OBJECT (widget), "password-save");
-  priv->password_save = GPOINTER_TO_INT (data);
+  if (gtk_toggle_button_get_active (button))
+    {
+      gpointer data;
+
+      data = g_object_get_data (G_OBJECT (button), "password-save");
+      priv->password_save = GPOINTER_TO_INT (data);
+    }
 }
 
 static void
@@ -267,11 +255,8 @@ pw_dialog_got_response (GtkDialog         *dialog,
                         gint               response_id,
                         GtkMountOperation *mount_op)
 {
-  GtkMountOperationPrivate *priv;
-  GMountOperation *op;
-
-  priv = mount_op->priv;
-  op = G_MOUNT_OPERATION (mount_op);
+  GtkMountOperationPrivate *priv = mount_op->priv;
+  GMountOperation *op = G_MOUNT_OPERATION (mount_op);
 
   if (response_id == GTK_RESPONSE_OK)
     {
@@ -449,6 +434,7 @@ gtk_mount_operation_ask_password (GMountOperation   *mount_op,
   GtkWidget *message_label;
   gboolean   can_anonymous;
   guint      rows;
+  const gchar *secondary;
 
   operation = GTK_MOUNT_OPERATION (mount_op);
   priv = operation->priv;
@@ -469,6 +455,7 @@ gtk_mount_operation_ask_password (GMountOperation   *mount_op,
   gtk_box_set_spacing (GTK_BOX (dialog->action_area), 6);
 
   gtk_window_set_resizable (window, FALSE);
+  gtk_window_set_title (window, "");
   gtk_window_set_icon_name (window, GTK_STOCK_DIALOG_AUTHENTICATION);
 
   gtk_dialog_add_buttons (dialog,
@@ -496,11 +483,33 @@ gtk_mount_operation_ask_password (GMountOperation   *mount_op,
   main_vbox = gtk_vbox_new (FALSE, 18);
   gtk_box_pack_start (GTK_BOX (hbox), main_vbox, TRUE, TRUE, 0);
 
-  message_label = gtk_label_new (message);
-  gtk_misc_set_alignment (GTK_MISC (message_label), 0.0, 0.5);
-  gtk_label_set_line_wrap (GTK_LABEL (message_label), TRUE);
-  gtk_box_pack_start (GTK_BOX (main_vbox), GTK_WIDGET (message_label),
-                      FALSE, FALSE, 0);
+  secondary = strstr (message, "\n");
+  if (secondary != NULL)
+    {
+      gchar *s;
+      gchar *primary;
+
+      primary = g_strndup (message, secondary - message + 1);
+      s = g_strdup_printf ("<big><b>%s</b></big>%s", primary, secondary);
+
+      message_label = gtk_label_new (NULL);
+      gtk_label_set_markup (GTK_LABEL (message_label), s);
+      gtk_misc_set_alignment (GTK_MISC (message_label), 0.0, 0.5);
+      gtk_label_set_line_wrap (GTK_LABEL (message_label), TRUE);
+      gtk_box_pack_start (GTK_BOX (main_vbox), GTK_WIDGET (message_label),
+                          FALSE, TRUE, 0);
+
+      g_free (s);
+      g_free (primary);
+    }
+  else
+    {
+      message_label = gtk_label_new (message);
+      gtk_misc_set_alignment (GTK_MISC (message_label), 0.0, 0.5);
+      gtk_label_set_line_wrap (GTK_LABEL (message_label), TRUE);
+      gtk_box_pack_start (GTK_BOX (main_vbox), GTK_WIDGET (message_label),
+                          FALSE, FALSE, 0);
+    }
 
   vbox = gtk_vbox_new (FALSE, 6);
   gtk_box_pack_start (GTK_BOX (main_vbox), vbox, FALSE, FALSE, 0);
@@ -579,15 +588,20 @@ gtk_mount_operation_ask_password (GMountOperation   *mount_op,
 
    if (flags & G_ASK_PASSWORD_SAVING_SUPPORTED)
     {
-      GtkWidget  *choice;
-      GtkWidget  *remember_box;
-      GSList     *group;
+      GtkWidget    *choice;
+      GtkWidget    *remember_box;
+      GSList       *group;
+      GPasswordSave password_save;
 
       remember_box = gtk_vbox_new (FALSE, 6);
       gtk_box_pack_start (GTK_BOX (vbox), remember_box,
                           FALSE, FALSE, 0);
 
-      choice = gtk_radio_button_new_with_mnemonic (NULL, _("_Forget password immediately"));
+      password_save = g_mount_operation_get_password_save (mount_op);
+      
+      choice = gtk_radio_button_new_with_mnemonic (NULL, _("Forget password _immediately"));
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (choice),
+                                    password_save == G_PASSWORD_SAVE_NEVER);
       g_object_set_data (G_OBJECT (choice), "password-save",
                          GINT_TO_POINTER (G_PASSWORD_SAVE_NEVER));
       g_signal_connect (choice, "toggled",
@@ -595,7 +609,9 @@ gtk_mount_operation_ask_password (GMountOperation   *mount_op,
       gtk_box_pack_start (GTK_BOX (remember_box), choice, FALSE, FALSE, 0);
 
       group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (choice));
-      choice = gtk_radio_button_new_with_mnemonic (group, _("_Remember password until you logout"));
+      choice = gtk_radio_button_new_with_mnemonic (group, _("Remember password until you _logout"));
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (choice),
+                                    password_save == G_PASSWORD_SAVE_FOR_SESSION);
       g_object_set_data (G_OBJECT (choice), "password-save",
                          GINT_TO_POINTER (G_PASSWORD_SAVE_FOR_SESSION));
       g_signal_connect (choice, "toggled",
@@ -603,7 +619,9 @@ gtk_mount_operation_ask_password (GMountOperation   *mount_op,
       gtk_box_pack_start (GTK_BOX (remember_box), choice, FALSE, FALSE, 0);
 
       group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (choice));
-      choice = gtk_radio_button_new_with_mnemonic (group, _("_Remember forever"));
+      choice = gtk_radio_button_new_with_mnemonic (group, _("Remember _forever"));
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (choice),
+                                    password_save == G_PASSWORD_SAVE_PERMANENTLY);
       g_object_set_data (G_OBJECT (choice), "password-save",
                          GINT_TO_POINTER (G_PASSWORD_SAVE_PERMANENTLY));
       g_signal_connect (choice, "toggled",
@@ -720,6 +738,22 @@ gtk_mount_operation_ask_question (GMountOperation *op,
   g_object_ref (op);
 }
 
+static void
+gtk_mount_operation_aborted (GMountOperation *op)
+{
+  GtkMountOperationPrivate *priv;
+
+  priv = GTK_MOUNT_OPERATION (op)->priv;
+
+  if (priv->dialog != NULL)
+    {
+      gtk_widget_destroy (GTK_WIDGET (priv->dialog));
+      priv->dialog = NULL;
+      g_object_notify (G_OBJECT (op), "is-showing");
+      g_object_unref (op);
+    }
+}
+
 /**
  * gtk_mount_operation_new:
  * @parent: transient parent of the window, or %NULL
@@ -767,6 +801,8 @@ gtk_mount_operation_is_showing (GtkMountOperation *op)
  *
  * Sets the transient parent for windows shown by the
  * #GtkMountOperation.
+ *
+ * Since: 2.14
  */
 void
 gtk_mount_operation_set_parent (GtkMountOperation *op,
